@@ -27,19 +27,16 @@ This modules provides a library of functions that calculate waveform parameters
 from other parameters. All exposed functions in this module's namespace return
 one parameter given a set of inputs.
 """
-from __future__ import division
 
 import copy
 import numpy
 import lal
-import lalsimulation as lalsim
 from pycbc.detector import Detector
 import pycbc.cosmology
 from .coordinates import spherical_to_cartesian as _spherical_to_cartesian
-try:
-    import pykerr
-except ImportError:
-    pykerr = None
+
+pykerr = pycbc.libutils.import_optional('pykerr')
+lalsim = pycbc.libutils.import_optional('lalsimulation')
 
 #
 # =============================================================================
@@ -796,9 +793,8 @@ def snr_from_loglr(loglr):
     if singleval:
         loglr = numpy.array([loglr])
     # temporarily quiet sqrt(-1) warnings
-    numpysettings = numpy.seterr(invalid='ignore')
-    snrs = numpy.sqrt(2*loglr)
-    numpy.seterr(**numpysettings)
+    with numpy.errstate(invalid="ignore"):
+        snrs = numpy.sqrt(2*loglr)
     snrs[numpy.isnan(snrs)] = 0.
     if singleval:
         snrs = snrs[0]
@@ -842,8 +838,6 @@ def get_lm_f0tau(mass, spin, l, m, n=0, which='both'):
         Returned if ``which`` is 'both' or 'tau'.
         The damping time of the QNM(s), in seconds.
     """
-    if pykerr is None:
-        raise ImportError("pykerr must be installed to get f0 or tau")
     # convert to arrays
     mass, spin, l, m, n, input_is_array = ensurearray(
         mass, spin, l, m, n)
