@@ -99,9 +99,10 @@ def from_cli(opt, length, delta_f, low_frequency_cutoff,
                 psd = from_xml(psd_file_name, length, delta_f, f_low,
                                ifo_string=opt.psd_file_xml_ifo_string,
                                root_name=opt.psd_file_xml_root_name)
-        # Set values < flow to the value at flow
+        # Set values < flow to the value at flow (if flow > 0)
         kmin = int(low_frequency_cutoff / psd.delta_f)
-        psd[0:kmin] = psd[kmin]
+        if kmin > 0:
+            psd[0:kmin] = psd[kmin]
 
         psd *= dyn_range_factor ** 2
 
