@@ -3,8 +3,9 @@ from pycbc.results.metadata import *
 from pycbc.results.versioning import *
 from pycbc.results.color import *
 from pycbc.results.plot import *
-from pycbc.results.legacy_grb import *
+from pycbc.results.psd import *
 from pycbc.results.layout import *
 from pycbc.results.dq import *
 from pycbc.results.str_utils import *
+from pycbc.results.pygrb_postprocessing_utils import *
 from pycbc.results.pygrb_plotting_utils import *
