@@ -17,7 +17,6 @@
 """
 Provides a class representing a frequency series.
 """
-from __future__ import division
 import os as _os, h5py
 from pycbc.types.array import Array, _convert, zeros, _noreal
 import lal as _lal
@@ -38,15 +37,6 @@ class FrequencySeries(Array):
         Sample data type.
     copy : boolean, optional
         If True, samples are copied to a new array.
-
-    Attributes
-    ----------
-    delta_f : float
-        Frequency spacing
-    epoch : lal.LIGOTimeGPS
-        Time at 0 index.
-    sample_frequencies : Array
-        Frequencies that each index corresponds to.
     """
 
     def __init__(self, initial_array, delta_f=None, epoch="", dtype=None, copy=True):
@@ -484,6 +474,7 @@ class FrequencySeries(Array):
                            dtype=real_same_precision_as(self)),
                            delta_t=delta_t)
         ifft(tmp, f)
+        f._delta_t = delta_t
         return f
 
     @_noreal
