@@ -24,20 +24,19 @@
 """
 This module is responsible for setting up the part of a pycbc workflow that
 will generate the injection files to be used for assessing the workflow's
-ability to detect predicted signals. (In ihope parlance, this sets up the
-inspinj jobs). Full documentation for this module can be found here:
+ability to detect predicted signals.
+Full documentation for this module can be found here:
 https://ldas-jobs.ligo.caltech.edu/~cbc/docs/pycbc/NOTYETCREATED.html
 """
 
 import logging
 import os.path
-from six.moves import configparser as ConfigParser
+import configparser as ConfigParser
 from pycbc.workflow.core import FileList, make_analysis_dir, Node
 from pycbc.workflow.core import Executable, resolve_url_to_file
 from pycbc.workflow.jobsetup import (LalappsInspinjExecutable,
         LigolwCBCJitterSkylocExecutable, LigolwCBCAlignTotalSpinExecutable,
-        PycbcDarkVsBrightInjectionsExecutable, LigolwAddExecutable,
-        select_generic_executable)
+        PycbcDarkVsBrightInjectionsExecutable, select_generic_executable)
 
 def veto_injections(workflow, inj_file, veto_file, veto_name, out_dir, tags=None):
     tags = [] if tags is None else tags
@@ -68,6 +67,19 @@ class PyCBCOptimalSNRExecutable(Executable):
                                  '--output-file')
         return node
 
+
+class PyCBCMergeHDFExecutable(Executable):
+    """Merge HDF injection files executable class"""
+    current_retention_level = Executable.MERGED_TRIGGERS
+
+    def create_node(self, workflow, input_files):
+        node = Node(self)
+        node.add_input_list_opt('--injection-files', input_files)
+        node.new_output_file_opt(workflow.analysis_time, '.hdf',
+                                 '--output-file')
+        return node
+
+
 def compute_inj_optimal_snr(workflow, inj_file, precalc_psd_files, out_dir,
                             tags=None):
     "Set up a job for computing optimal SNRs of a sim_inspiral file."
@@ -78,7 +90,8 @@ def compute_inj_optimal_snr(workflow, inj_file, precalc_psd_files, out_dir,
         factor = int(workflow.cp.get_opt_tags('workflow-optimal-snr',
                                               'parallelization-factor',
                                               tags))
-    except ConfigParser.Error:
+    except Exception as e:
+        logging.warning(e)
         factor = 1
 
     if factor == 1:
@@ -106,16 +119,21 @@ def compute_inj_optimal_snr(workflow, inj_file, precalc_psd_files, out_dir,
         opt_snr_split_files += [node.output_files[0]]
         workflow += node
 
-    llwadd_exe = LigolwAddExecutable(workflow.cp, 'optimal_snr_merge',
-                                     ifos=workflow.ifos, out_dir=out_dir,
-                                     tags=tags)
-    llwadd_exe.update_current_retention_level(Executable.MERGED_TRIGGERS)
-    merge_node = llwadd_exe.create_node(workflow.analysis_time,
-                                        opt_snr_split_files,
-                                        use_tmp_subdirs=False)
-    workflow += merge_node
+    hdfcombine_exe = PyCBCMergeHDFExecutable(
+        workflow.cp,
+        'optimal_snr_merge',
+        ifos=workflow.ifos,
+        out_dir=out_dir,
+        tags=tags
+    )
 
-    return merge_node.output_files[0]
+    hdfcombine_node = hdfcombine_exe.create_node(
+        workflow,
+        opt_snr_split_files
+    )
+    workflow += hdfcombine_node
+
+    return hdfcombine_node.output_files[0]
 
 def cut_distant_injections(workflow, inj_file, out_dir, tags=None):
     "Set up a job for removing injections that are too distant to be seen"
