@@ -29,9 +29,8 @@ workflows.
 
 # FIXME: Is this module still relevant for any code? Can it be removed?
 
-from __future__ import division
 import logging
-from six.moves import configparser as ConfigParser
+import configparser as ConfigParser
 from pycbc.workflow.core import FileList
 from pycbc.workflow.core import make_analysis_dir, resolve_url_to_file
 
